<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/hashed_array.php';
require_once 'lib/tv/abstract_tv.php';
require_once 'lib/tv/default_epg_item.php';
require_once 'lib/tv/epg_iterator.php';

require_once 'oft_channel.php';

///////////////////////////////////////////////////////////////////////////

class OftTv extends AbstractTv
{
    private $session;

    ///////////////////////////////////////////////////////////////////////

    public function __construct($session)
    {
        $this->session = $session;

        parent::__construct(
            AbstractTv::MODE_CHANNELS_1_TO_N,
            true,
            false);
    }

    public function get_fav_icon_url()
    {
        return $this->session->get_icon('favorites.png');
    }

    ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    protected function load_channels(&$plugin_cookies)
    {
        $this->session->check_logged_in();

        $settings = $this->session->get_settings();
        $buffering_ms = ($settings->stb_buffer) * 1000;
        $default_timeshift_hours = $settings->time_shift;

        $this->channels = new HashedArray();
        $this->groups = new HashedArray();

        $this->groups->put(
            new FavoritesGroup(
                $this,
                '__favorites',
                'Ulubione',
                $this->session->get_icon('favorites.png')));

        $this->groups->put(
            new AllChannelsGroup(
                $this,
                'Wszystkie kanały',
                $this->session->get_icon('all.png')));

        $num_groups = 0;
        $num_channels = 0;
        $num_protected = 0;
        $num_have_archive = 0;
        $timeshift_hours = $default_timeshift_hours;
        //file_get_contents('http://megaimpuls.com:8102/dune/log_request.php?url='.urlencode('olololololo'));
        foreach ($this->session->get_channel_list()->groups as $g)
        {
            //file_get_contents('http://megaimpuls.com:8102/dune/log_request.php?url='.urlencode('pass x'));
            $oft_group = new DefaultGroup(
                $g->id,
                $g->user_title,
                '');

            $this->groups->put($oft_group);
            $num_groups++;

            foreach ($g->channels as $c)
            {
                $have_archive = isset($c->has_archive) ?
                    ($c->has_archive == 1) : false;
                $is_protected = isset($c->protected) ?
                    ($c->protected == 1) : false;

                // TODO: timeshift
                

                $oft_channel = new OftChannel(
                    $c->id,
                    $c->name,
                    $this->session->get_channel_icon($c->icon),
                    $have_archive, $is_protected,
                    $buffering_ms, $timeshift_hours);
                $this->channels->put($oft_channel);

                $oft_channel->add_group($oft_group);
                $oft_group->add_channel($oft_channel);

                $num_channels++;
                if ($is_protected)
                    $num_protected++;
                if ($have_archive)
                    $num_have_archive++;
            }
        }

        hd_print("OFT: $num_groups groups and ".
            "$num_channels channels ($num_have_archive have archive, ".
            "$num_protected protected)\n Ico url");
    }

    public function get_tv_info(MediaURL $media_url, &$plugin_cookies)
    {
        $this->session->ensure_logged_in($plugin_cookies);

        return parent::get_tv_info($media_url, &$plugin_cookies);
    }

    ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    public function get_tv_stream_url($playback_url, &$plugin_cookies)
    {
        return $this->session->api_get_stream_url($playback_url);
    }

    public function get_tv_playback_url($channel_id, $archive_ts, $protect_code, &$plugin_cookies)
    {
        $this->ensure_channels_loaded($plugin_cookies);
        $timeshift_hours = $this->session->get_settings()->time_shift;
        $url = sprintf(OFT_GET_URL_URL,
            OFT::$SERVER,
            $this->session->get_sid(),
            $channel_id);
//        hd_print("Get url -->".$channel_id."\nSID ->".$this->session->get_sid());
        if (intval($archive_ts) > 0){
//            hd_print("archive_ts->$archive_ts");
            $archive_ts = intval($archive_ts - ($timeshift_hours * 3600));
            $url .= "&uts=$archive_ts";}
        if (isset($protect_code) && $protect_code !== '')
            $url .= "&protect_code=$protect_code";
        if (intval($timeshift_hours)>0)
            $url.="&time_shift=$timeshift_hours";
        hd_print("Get url -->".$url);
        return $url;
    }

    ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    public function get_day_epg_iterator($channel_id, $day_start_ts, &$plugin_cookies)
    {
        $this->ensure_channels_loaded($plugin_cookies);
        $timeshift_hours = $this->session->get_settings()->time_shift;
        //$day_str = gmstrftime('%d%m%y', $day_start_ts);
        $url = sprintf(OFT_EPG_URL,
            OFT::$SERVER,           
            $this->session->get_sid(),
            $channel_id,
            $day_start_ts);
        
        try
        {
            $oft_epg = $this->session->api_call($url);
        }
        catch (Exception $e)
        {
            throw $this->session->dune_api_exception($e,
                'EPG request failed.',
                true);
        }

        $epg_items = array();

        foreach ($oft_epg->channels[0]->epg as $epg)
        {
            $progname = $epg->title;

            $arr = explode("\n", $epg->title, 2);
            $name = count($arr) >= 1 ? trim($arr[0]) : '';
            $desarr = explode("\n", $epg->info, 2);
            $description = count($desarr) >= 1 ? trim($desarr[0]) : '';

            $start = intval($epg->begin + ($timeshift_hours * 3600));
            $end = -1;
//            hd_print("\nStart->".$start);
            $epg_items[] = new DefaultEpgItem(
                $name, $description, $start, $end);
        }
        
        return new EpgIterator($epg_items, $day_start_ts, $day_start_ts + (86400*3));
    }

    public function get_archive(MediaURL $media_url)
    {
        return $this->session->get_archive();
    }

    public function folder_entered(MediaURL $media_url, &$plugin_cookies)
    {
        if (!isset($media_url->screen_id) ||
            $media_url->screen_id === TvGroupListScreen::ID)
        {
            $this->session->logout();
        }

        $this->session->ensure_logged_in($plugin_cookies);
    }

    // Hook for adding special group items.
	///////// OFT ///////////
//    public function add_special_groups(&$items)
//    {
//         //array_unshift($items,
//         array_push($items,
//            array
//            (
//                PluginRegularFolderItem::media_url =>
//                    MediaURL::encode(
//                        array
//                        (
//                            'screen_id' => OftVodRootScreen::ID,
//                        )),
//                PluginRegularFolderItem::caption => 'Видеотека',
//                PluginRegularFolderItem::view_item_params => array
//                (
//                    ViewItemParams::icon_path =>
//                        $this->session->get_icon('mov_root.png')
//                )
//            )/*,
//            array
//            (
//                PluginRegularFolderItem::media_url => OftSetupScreen::get_media_url_str(),
//                PluginRegularFolderItem::caption => 'Настройки',
//                PluginRegularFolderItem::view_item_params => array
//                (
//                    ViewItemParams::icon_path =>
//                        $this->session->get_icon('mov_settings.png')
//                )
//            )*/
//            );
//    }

}



///////////////////////////////////////////////////////////////////////////
?>
